package de.intevation.flys.client.shared.model;


public class IntegerArrayData implements Data {

    public static final String TYPE = "intarray";


    protected String label;
    protected String description;

    protected int[] values;


    public IntegerArrayData() {
    }


    public IntegerArrayData(String label, String description, int[] values) {
        this.label       = label;
        this.description = description;
        this.values      = values;
    }


    /**
     * Returns the label of the item.
     *
     * @return the label.
     */
    public String getLabel() {
        return label;
    }


    /**
     * Returns the description of the item.
     *
     * @return the description.
     */
    public String getDescription() {
        return description;
    }


    /**
     * Returns the type of the item.
     *
     * @return the type.
     */
    public String getType() {
        return "intarray";
    }


    /**
     * Returns a DataItem which value is a string that consists of the integer
     * values separated by a ';'.
     *
     * @return the DataItem.
     */
    public DataItem[] getItems() {
        if (values == null || values.length == 0) {
            return new DataItem[0];
        }

        StringBuilder sb    = new StringBuilder();
        boolean       first = true;

        for (int value: values) {
            if (first) {
                sb.append(String.valueOf(value));
            }
            else {
                sb.append(";" + String.valueOf(value));
            }
        }

        String  value = sb.toString();
        DataItem item = new DefaultDataItem(value, value, value);

        return new DataItem[] { item };
    }


    /**
     * Returns the values as array.
     *
     * @return the values as array.
     */
    public int[] getValues() {
        return values;
    }


    /**
     * @return always null.
     */
    public DataItem getDefault() {
        return null;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
